import ms from 'ms';
import { shortId } from '../helper/IdGenerate.js';
import QRCode from '../helper/QRCode.js';
import MemoryDB from '../database/MemoryDB.js';
import Base64 from '../helper/Base64.js';

const defaultExpirationTime = process.env.EXPIRE_KEY_TIME ? ms(process.env.EXPIRE_KEY_TIME) : ms('3d');

class UrlShortener {
  static async shorten(req, url, expirationTime = defaultExpirationTime) {
    const id = shortId(url);
    const key = `url:${id}`;
    await MemoryDB.set(key, url, expirationTime);

    const shortUrl = `${req.get('host')}/${id}`;
    const qrCode = await QRCode.create(shortUrl);
    const qrCodeBase64 = Base64.encode(qrCode);
    const imageFormat = 'svg+xml';
    return { shortUrl, qrCode: `data:image/${imageFormat};base64,${qrCodeBase64}` };
  }

  static async extend(key) {
    let url = await MemoryDB.get(`url:${key}`);
    return url;
  }
}

const { shorten, extend } = UrlShortener;

export {
  shorten,
  extend,
}

export default new UrlShortener();