import morgan from 'morgan';
import rfs from 'rotating-file-stream';

class Log {
  register(server) {
    const {
      LOG_PATH,
      LOG_FILE_NAME,
      LOG_FORMAT,
      LOG_MAX_FILES,
      LOG_ROTATE_INTERVAL,
    } = process.env;
    if (!LOG_PATH || LOG_PATH.includes('<>')) return;
    const isEmpty = (value) => ( value || '<>' ).includes('<>');
    const isInvalidNumber = (value) => Number.isNaN(Number(value));
    const logFormat = isEmpty(LOG_FORMAT) ? '[:date] [:method] [:url] [:status] [:response-time ms]' : LOG_FORMAT;
    const interval = isEmpty(LOG_ROTATE_INTERVAL) ? '1d' : LOG_ROTATE_INTERVAL;
    const maxFiles = isEmpty(LOG_MAX_FILES) || isInvalidNumber(LOG_MAX_FILES) ? 90 : Number(LOG_MAX_FILES);
    const logFileName = isEmpty(LOG_FILE_NAME) ? 'access.log' : LOG_FILE_NAME;
    const accessLogStream = rfs.createStream(logFileName, {
      interval,
      path: LOG_PATH,
      maxFiles,
      intervalBoundary: true,
      initialRotation: true,
    });
    server.use(morgan(logFormat, { stream: accessLogStream }));
  }
}

export default new Log();